const Mesa = require('vendor/Mesa.js');
const Shopify= require('vendor/Shopify.js');

/**
 * A Mesa Script exports a class with a script() method.
 */
module.exports = new class {

  /**
   * Mesa Script
   *
   * @param {object} payload The payload data
   * @param {object} context Additional context about this task
   */
  script = (payload, context) => {
    Mesa.output.next({"is_fulfillable": this.isFulfillable(context)});
  }

  isFulfillable = (context) => {
    let vars = context.steps;
    let order = vars.shopify_4;

    let skus = order.line_items.map(item => `${item.sku}: ${item.quantity}`).join(', ');

    Mesa.trigger.setTaskExternalData({
      label: "SKUs: " + skus
    });

    let inventoryItemAvailable = vars.shopify.available;
    for (let lineItem of order.line_items) {
      let variantResponse = Shopify.get('/admin/variants/' + lineItem.variant_id + '.json');
      let variant = variantResponse.variant;
      
      Mesa.log.info("Debug Conditional SKU " + lineItem.sku + " - quantity: " + lineItem.quantity + " - variant available: " + variant.inventory_quantity + ", policy: " + variant.inventory_policy);
      if (variant.inventory_policy == 'deny' && variant.inventory_quantity < lineItem.quantity) {
        Mesa.log.info("Debug Conditional False");
        return false;
      }
    }

    return true;
  }
}
